;; Generated package description from cond-let.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "cond-let" "0.2.2" "Additional and improved binding conditionals" '((emacs "28.1")) :commit "8bf87d45e169ebc091103b2aae325aece3aa804d" :keywords '("extensions") :url "https://github.com/tarsius/cond-let")
